Use and citations
=================

Citation
--------

If you make use of this code in your work, please cite::

    @misc{Cheong2022diffoptics,
        author={Cheong Sanha, Sean Gasiorowski, Kagan Michael, Safdari Murtaza, Schwartzman Ariel, Vandegar Maxime},
        title={GradOptics: Differentiable Optics via Ray Tracing},
        url={https://differentiable-optics.readthedocs.io}
        year={2022},
    }

Use in Publications
-------------------

::

    @misc{Cheong2022lfid,
        author={Cheong Sanha, Frisch Josef, Sean Gasiorowski, Hogan Jason, Kagan Michael, Safdari Murtaza, Schwartzman Ariel, Vandegar Maxime},
        title={Novel Light Field Imaging Device with Enhanced Light Collection for Cold Atom Clouds},
        year={2022},
    }